# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litepie/message/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litepie\\Message\\": "packages/litepie/message/src",
            "Litepie\\Message\\Seeders\\": "packages/litepie/message/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litepie\Message\Providers\MessageServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Message'  => Litepie\Message\Facades\Message::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litepie\\Message\\Seeders\\MessageTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litepie\Message\Providers\MessageServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litepie\Message\Providers\MessageServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litepie\Message\Providers\MessageServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/message/{modulename}

**User**

    http://path-to-route-folder/user/message/{modulename}

**Public**

    http://path-to-route-folder/messages


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/message/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/message/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/message/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/message/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/message/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/message/{modulename}/{slug}
    METHOD: GET