<?php

namespace Litepie\Message\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Litepie\Message\Interfaces\MessageRepositoryInterface;
use Litepie\Message\Repositories\Eloquent\Filters\MessagePublicFilter;
use Litepie\Message\Repositories\Eloquent\Presenters\MessageListPresenter;

class MessagePublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        MessageRepositoryInterface $message
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('litepie.message.modules'), 'message', guard_url('message'));
        $this->repository = $message;
    }

    /**
     * Show message's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(MessagePublicFilter::class)
            ->setPresenter(MessageListPresenter::class)
            ->select('messages.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('message::message.names'))
            ->view('message::public.message.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show message.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('message::message.name'))
            ->view('message::public.message.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
